from setuptools import setup

setup(name='drz',
      version='0.1',
      description='A painless deployment system for modern code',
      url='https://github.com/kilometercreative/Drizzle',
      author='Kaeden Wile',
      author_email='kaeden@kilometercreative.com',
      license='MIT',
      packages=['drz'],
      zip_safe=False)
